import typer
from pathlib import Path
from netdb_client.api41 import APIEndpoint, APISession, dns

from netdb_client.util.click_helper import netdb_config_callback, netdb_endpoint_callback

app = typer.Typer()


@app.command(context_settings={'help_option_names': ['-h', '--help'], 'max_content_width': 120})
def main(
    _netdb_config: Path = typer.Option(
        Path('~/.config/netdb_client.ini'),
        '--netdb-config',
        help='netdb auth config file path',
        callback=netdb_config_callback,
        is_eager=True,
        expose_value=False,
    ),
    netdb_endpoint: str = typer.Option(
        None,
        '--netdb-endpoint',
        envvar='NETDB_ENDPOINT',
        help='endpoint to use. Config: [DEFAULT]: endpoint',
        callback=netdb_endpoint_callback,
        expose_value=False,
    ),
    netdb_base_url: str = typer.Option(
        None, '--netdb-base-url', envvar='NETDB_BASE_URL', help='webapi server. Config: [$endpoint]: base_url'
    ),
    netdb_token: str = typer.Option(
        None, '--netdb-token', envvar='NETDB_TOKEN', show_default=False, help='user API token. Config: [$endpoint]: token'
    ),
):
    netdb_enpoint = APIEndpoint(base_url=netdb_base_url, token=netdb_token)
    netdb_api = APISession(netdb_enpoint)

    fqdn = dns.Fqdn.list(netdb_api, value_old='net.scc.kit.edu')

    print(fqdn)


if __name__ == '__main__':
    app()
