import configparser
import stat


class NETDBConfigError(Exception):
    pass


class NETDBConfig:
    def __init__(self, config_path):
        self.config = configparser.ConfigParser()
        config_path_expanded = config_path.expanduser()
        if config_path_expanded.is_file():
            if config_path_expanded.stat().st_mode & stat.S_IRWXO:
                raise NETDBConfigError(
                    'Config file is readable by others. Please set it at least to 600 but never other-readable.'
                )
            self.config.read(config_path_expanded)

        self.default_endpoint = self.config.get('DEFAULT', 'endpoint', fallback=None)

    def endpoint(self, endpoint: str = None) -> str:
        if endpoint is None:
            endpoint = self.default_endpoint

        if endpoint is None:
            raise NETDBConfigError('No endpoint was provided.')

        return endpoint

    def base_url(self, endpoint: str = None) -> str:
        base_url = self.config.get(self.endpoint(endpoint), 'base_url', fallback=None)

        if base_url is None:
            base_url = endpoint

        return base_url

    def token(self, endpoint: str = None) -> str:
        token = self.config.get(self.endpoint(endpoint), 'token', fallback=None)

        if token is None:
            raise NETDBConfigError('No token was provided')

        return token
